@@ -242,38 +242,7 @@ class OrderedBTreeFolderBase(OrderSupport, BTreeFolder2Base):
             # make a copy
             return list(self._order)
 
-    security.declareProtected(Permissions.access_contents_information,
-                              'keys')
-    def keys(self):
-        return self.objectIds()
-
-    security.declareProtected(Permissions.access_contents_information,
-                              'objectValues')
-    def objectValues(self, spec=None):
-        # Returns a list of actual subobjects of the current object.
-        # If 'spec' is specified, returns only objects whose meta_type
-        # match 'spec'.
-        return Products.ZCatalog.Lazy.LazyMap(
-            self._getOb, self.objectIds(spec))
-
-    security.declareProtected(Permissions.access_contents_information,
-                              'values')
-    values = objectValues
-
-    security.declareProtected(Permissions.access_contents_information,
-                              'objectItems')
-    def objectItems(self, spec=None):
-        # Returns a list of (id, subobject) tuples of the current object.
-        # If 'spec' is specified, returns only objects whose meta_type match
-        # 'spec'
-        return Products.ZCatalog.Lazy.LazyMap(
-            lambda id, _getOb=self._getOb: (id, _getOb(id)),
-            self.objectIds(spec))
-
-    security.declareProtected(Permissions.access_contents_information,
-                              'items')
-    items = objectItems
-
+    keys = objectIds
 
 InitializeClass(OrderedBTreeFolderBase)
 
